@@ -1,6 +1,6 @@
 # pylint: disable=missing-module-docstring
 # pylint: disable=line-too-long
-from typing import Optional, Generator, Dict
+from typing import Generator
 from datetime import datetime
 import gzip
 import requests
@@ -23,7 +23,7 @@ def _build_headers(unit_name: str, ftype: str = "json"):
     return headers
 
 
-def _convert_brreg_date(date: Optional[str]):
+def _convert_brreg_date(date: str | None):
     """converts brreg date string to datetime"""
     if date is None:
         return None
@@ -68,7 +68,7 @@ def _get_unit_record_from_update_single(update: Update, unit_name: str, download
     return _build_unit_record(update, fact, download_date)
 
 
-def _get_unit_record_from_update_batch(orgnr_update_lkp: Dict[str, Update], unit_name: str, download_date: datetime, page_size: int = 500):
+def _get_unit_record_from_update_batch(orgnr_update_lkp: dict[str, Update], unit_name: str, download_date: datetime, page_size: int = 500):
     """Returns {orgnr: record} constructed by searching for details for orgs in given {orgnr: update}
     NB: the dict of updates may have elements removed.
     Org details will not be found if the org has been deleted at any point in the past,
@@ -88,7 +88,7 @@ def _get_unit_record_from_update_batch(orgnr_update_lkp: Dict[str, Update], unit
                 _build_unit_record(orgnr_update_lkp.pop(fact["organisasjonsnummer"]), fact, download_date)
             for fact in facts
         }
-    
+
     return orgnr_record_lkp
 
 
